PreCommitHook

Struct PreCommitHook 

pub struct PreCommitHook {
Show 21 fields pub id: String, pub additional_dependencies: Option<BTreeSet<String>>, pub alias: Option<String>, pub always_run: Option<bool>, pub args: Option<Vec<String>>, pub entry: Option<String>, pub exclude: Option<String>, pub exclude_types: Option<BTreeSet<FileType>>, pub description: Option<String>, pub files: Option<String>, pub language: Option<Language>, pub language_version: Option<String>, pub log_file: Option<String>, pub minimum_pre_commit_version: Option<usize>, pub name: Option<String>, pub pass_filenames: Option<bool>, pub require_serial: Option<bool>, pub stages: Option<BTreeSet<Stage>>, pub types: Option<BTreeSet<FileType>>, pub types_or: Option<BTreeSet<FileType>>, pub verbose: Option<bool>,
}
Description for a pre-commit hook. https://pre-commit.com/#pre-commit-configyaml—hooks

Fields

id: String

An identifier of the current hook https://pre-commit.com/#pre-commit-configyaml—hooks

additional_dependencies: Option<BTreeSet<String>>

A list of additional_dependencies of the current hook https://pre-commit.com/#pre-commit-configyaml—hooks

alias: Option<String>

An additional identifier of the current hook for pre-commit run <hookid> https://pre-commit.com/#pre-commit-configyaml—hooks

always_run: Option<bool>

Run the current hook when no files matched https://pre-commit.com/#pre-commit-configyaml—hooks

args: Option<Vec<String>>

List of additional parameters to pass to the current hook https://pre-commit.com/#pre-commit-configyaml—hooks

entry: Option<String>

A command of the current hook https://pre-commit.com/#pre-commit-configyaml—hooks

exclude: Option<String>

Exclude files that were matched by files.

exclude_types: Option<BTreeSet<FileType>>

A list of file types to exclude of the current hook https://pre-commit.com/#pre-commit-configyaml—hooks

description: Option<String>

Description of the hook. used for metadata purposes only.

files: Option<String>

The pattern of files to run on.

language: Option<Language>

A language the current hook is written in https://pre-commit.com/#pre-commit-configyaml—hooks

language_version: Option<String>

Mappings for the default language versions of the current project https://pre-commit.com/#pre-commit-configyaml—top-level

log_file: Option<String>

A log file of the current hook

minimum_pre_commit_version: Option<usize>

Allows one to indicate a minimum compatible pre-commit version.

name: Option<String>

Name of the hook - shown during hook execution.

pass_filenames: Option<bool>

Whether to pass filenames to the current hook or not https://pre-commit.com/#pre-commit-configyaml—hooks

require_serial: Option<bool>

If true this hook will execute using a single process instead of in parallel.

stages: Option<BTreeSet<Stage>>

A stage of the current hook https://pre-commit.com/#pre-commit-configyaml—hooks

types: Option<BTreeSet<FileType>>

List of file types to run on (AND).

types_or: Option<BTreeSet<FileType>>

List of file types to run on (OR).

verbose: Option<bool>

Display an output of the current hook even it passes https://pre-commit.com/#pre-commit-configyaml—hooks